# Litestar Example

This example shows how to integrate [Litestar](https://github.com/litestar-org/litestar/) with [openapipages](https://github.com/hasansezertasan/openapipages).

## How to run this example

Clone the repository and navigate to this example:

```shell
git clone https://github.com/hasansezertasan/openapipages.git
cd openapipages/examples/litestar
```

> This example uses [`uv`](https://docs.astral.sh/uv/) to manage its dependencies and developer environment.

Run the example using `uv`, which will manage the environment and dependencies automatically:

> The `include_in_schema` parameter is set to `False` in each endpoint to avoid including these endpoints in the OpenAPI Spec.

```shell
uv run main.py
```
